;***GDI+ wrapper file***
;nxSoftware.com 2010.

;Demo program.
;Creating images.
;*******************************************************************************************

;In this demo we create a 32-bit GDI+ image (a memory bitmap) of a given width, height and pixel-format and then copy the bits
;from a 24-bit bitmap to it.
;We then run through our GDI+ bitmap and set all pixels alpha values to 128 making them semi-transparent.

;We start by loading up the 24-bit bmp using PB's image commands.
  LoadImage(1, "..\image1.bmp")
  GetObject_(ImageID(1), SizeOf(BITMAP), bmp.BITMAP)

XIncludeFile "..\..\gdiPlus.pbi"

If gdiPlus_Init() = #ok
  ;Create our empty image. Note how we match the width and height of our pre-loaded bmp. This is important if we are to copy the pixel bits across.
  image1.gdiPlus_Image = gdiPlus_CreateBitmap(bmp\bmWidth, bmp\bmHeight, #PixelFormat32bppARGB)
  If image1
    ;In order to set the pixel bits we need to first lock the bits of our GDI+ bitmap.
    ;This requires the use of a BitmapData structure. We use the BitmapData 'helper' class to help out.
    ;Note that the bmp image we have loaded is 'bottom-up' and thus we set a negative stride value and pass the address of the last row of
    ;the pixel data as representing the first row.
      bytesperrow = 4*((3*bmp\bmWidth+3)/4)
      lockedBitmapData.BitmapData
      gdiPlus_BitmapData(lockedBitmapData, bmp\bmWidth, bmp\bmHeight, -bytesperrow, #PixelFormat24bppRGB, bmp\bmBits + (bmp\bmHeight - 1) * bytesperrow)
    ;Lock the bits.
      gdiPlus_RectI(rc.RectI, 0, 0, bmp\bmWidth, bmp\bmHeight)
      image1\LockBits(rc, #ImageLockModeUserInputBuf|#ImageLockModeWrite, #PixelFormat24bppRGB, lockedBitmapData)
    ;Now unlock the bits. This will copy the bits from the temporary buffer to our GDI+ bitmap.
      image1\UnlockBits(lockedBitmapData)
    ;Lock the bits again but this time we request a buffer (rather than supply one ourselves) containing the bits in 32bppARGB format.
      If image1\LockBits(rc, #ImageLockModeWrite, #PixelFormat32bppARGB, lockedBitmapData) = #ok
        ;We run through changing making all pixels semi-transparent
        *rgba.RGBQUAD = lockedBitmapData\Scan0
        For i = 1 To bmp\bmHeight
          For j = 1 To bmp\bmWidth
            *rgba\rgbReserved = 128
            *rgba + SizeOf(RGBQUAD)
          Next
        Next 
        ;Now unlock the bits. This will copy the bits from the temporary buffer to our GDI+ bitmap.
          image1\UnlockBits(lockedBitmapData)
      EndIf
    ;Uncomment the following to save the image so that you can take a look at it etc.
;      image1\Save("createImage2.png", #GDIPLUS_PNG)
    image1\Destroy()
  EndIf
  gdiPlus_Free()
EndIf

; IDE Options = PureBasic 4.51 (Windows - x86)
; CursorPosition = 47
; FirstLine = 15
; EnableXP
; Executable = ..\nxExplorerBar.exe