﻿EnableExplicit
;/////////////////////////////////////////////////////////////////////////////////
;***GDI+ tools***
;================
;
;©nxSoftware.com 2010.
;=====================
;   Stephen Rodriguez (srod)
;   Created with Purebasic 4.5 for Windows.
;
;   Platforms:  Windows XP onwards (x86 and x64).
;
;http://msdn.microsoft.com/en-us/library/ms533846(VS.85).aspx
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
;This tool displays all GDI+ encoders, encoder parameters and info on their values.
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
;-CONSTANTS.

    Enumeration
      #Ok
    EndEnumeration

  ;Encoder parameter value types.
    Enumeration 
      #EncoderParameterValueTypeByte    = 1 
      #EncoderParameterValueTypeASCII
      #EncoderParameterValueTypeShort 
      #EncoderParameterValueTypeLong
      #EncoderParameterValueTypeRational
      #EncoderParameterValueTypeLongRange 
      #EncoderParameterValueTypeUndefined 
      #EncoderParameterValueTypeRationalRange
      #EncoderParameterValueTypePointer
    EndEnumeration
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
;-STRUCTURES.

  Structure GdiplusStartupInput
    GdiPlusVersion.i
    *DebugEventCallback.DebugEventProc
    SuppressBackgroundThread.i 
    SuppressExternalCodecs.i 
  EndStructure
  
  Structure GdiplusStartupOutput
    *NotificationHook.NotificationHookProc
    *NotificationUnhook.NotificationUnhookProc
  EndStructure
  
  ;Unsure of the following for x64.
  Structure ImageCodecInfo
    clsid.CLSID
    formatID.GUID
    *codecName.i
    *dllName.i
    *formatDescription.i
    *filenameExtension.i
    *mimeType.i
    flags.l
    version.l
    sigCount.l
    sigSize.l
    *sigPattern.byte
    *sigMask.byte
  EndStructure 

  Structure EncoderParameter
    guid.GUID
    NumberOfValues.l
    Type.l
    Value.i
  EndStructure

  Structure EncoderParameters
    Count.i
    Parameter.EncoderParameter[0]
  EndStructure
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
;-IMPORTS.
  CompilerSelect #PB_Compiler_Processor
    CompilerCase #PB_Processor_x86
      Import "..\GdiPlusx86.lib"
    CompilerCase #PB_Processor_x64
      Import "..\GdiPlusx64.lib"
  CompilerEndSelect
    GdiplusStartup(*token.INTEGER, *input.GdiplusStartupInput, *output.GdiplusStartupOutput=0) 
    GdiplusShutdown(token)
    GdipGetImageEncodersSize(*numEncoders.INTEGER, *size.INTEGER)
    GdipGetImageEncoders(numEncoders, size, *encoders)
    GdipGetEncoderParameterListSize(*image, *clsidEncoder.CLSID, *size.INTEGER)
    GdipGetEncoderParameterList(*image, *clsidEncoder.CLSID, size, *encoderParams.EncoderParameters)
    GdipLoadImageFromFile(filename.p-unicode, *image.INTEGER)
    GdipDisposeImage(*image)
  EndImport
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
;-DECLARES.
  Declare.i ShowEncoderParameters(*pImageCodecInfo.ImageCodecInfo)
;/////////////////////////////////////////////////////////////////////////////////


;-MAIN FUNCTION.

;/////////////////////////////////////////////////////////////////////////////////
Procedure DisplayEncoderParameters()
  Protected input.GdiplusStartupInput, token, numEncoders, size, mem, *pImageCodecInfo.ImageCodecInfo, i
  input\GdiPlusVersion = 1
  GdiplusStartup(@token, @input, #Null)
  If token
    If GdipGetImageEncodersSize(@numEncoders, @size) = #OK And size
      mem = AllocateMemory(size)
      If mem
        *pImageCodecInfo = mem
        If GdipGetImageEncoders(numEncoders, size, *pImageCodecInfo) = #OK 
          For i = 1 To numEncoders
            Debug PeekS(*pImageCodecInfo\MimeType, -1, #PB_Unicode)
            ShowEncoderParameters(*pImageCodecInfo)
            Debug ""
            *pImageCodecInfo  + SizeOf(ImageCodecInfo)
          Next
        EndIf
        FreeMemory(mem)
      EndIf
    EndIf
    GdiplusShutdown(token)
  EndIf
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;-UTILITY FUNCTIONS.

;/////////////////////////////////////////////////////////////////////////////////
;The following routine lists all parameters for the given encoder.
Procedure ShowEncoderParameters(*pImageCodecInfo.ImageCodecInfo)
  Protected image, listSize, *encoderParams.EncoderParameters, i, t1$
  ;Need to create a GDI+ image so that we can call the GdipGetEncoderParameterListSize() function.
  ;We simply load a dummy image.
  GdipLoadImageFromFile("..\Demos\image1.bmp", @image)
  If image
    GdipGetEncoderParameterListSize(image, *pImageCodecInfo\clsid, @listSize)
    Debug "    This encoder requires " + Str (ListSize) + " bytes."
    If listSize
      *encoderParams = AllocateMemory(listSize)
      If *encoderParams
        GdipGetEncoderParameterList(image, *pImageCodecInfo\clsid, ListSize, *encoderParams)        
        Debug "    There are " + Str(*encoderParams\Count) + " encoder parameters in the encoder array."
        For i = 0 To *encoderParams\Count - 1
          Debug "      Parameter[" + Str(i) + "]"
          t1$ = "unknown"
          If CompareMemory(*encoderParams\Parameter[i]\guid, ?GUID_EncoderCompression, SizeOf(GUID))
            t1$ = "compression"
          ElseIf CompareMemory(*encoderParams\Parameter[i]\guid, ?GUID_EncoderColorDepth, SizeOf(GUID))
            t1$ = "color depth"
          ElseIf CompareMemory(*encoderParams\Parameter[i]\guid, ?GUID_EncoderScanMethod, SizeOf(GUID))
            t1$ = "scan method"
          ElseIf CompareMemory(*encoderParams\Parameter[i]\guid, ?GUID_EncoderVersion, SizeOf(GUID))
            t1$ = "version"
          ElseIf CompareMemory(*encoderParams\Parameter[i]\guid, ?GUID_EncoderRenderMethod, SizeOf(GUID))
            t1$ = "render method"
          ElseIf CompareMemory(*encoderParams\Parameter[i]\guid, ?GUID_EncoderQuality, SizeOf(GUID))
            t1$ = "quality"
          ElseIf CompareMemory(*encoderParams\Parameter[i]\guid, ?GUID_EncoderTransformation, SizeOf(GUID))
            t1$ = "transformation"
          ElseIf CompareMemory(*encoderParams\Parameter[i]\guid, ?GUID_EncoderLuminanceTable, SizeOf(GUID))
            t1$ = "luminance table"
          ElseIf CompareMemory(*encoderParams\Parameter[i]\guid, ?GUID_EncoderChrominanceTable, SizeOf(GUID))
            t1$ = "chrominance table"
          ElseIf CompareMemory(*encoderParams\Parameter[i]\guid, ?GUID_EncoderSaveFlag, SizeOf(GUID))
            t1$ = "save flag"
          ElseIf CompareMemory(*encoderParams\Parameter[i]\guid, ?GUID_EncoderColorSpace, SizeOf(GUID))
            t1$ = "color space"
          ElseIf CompareMemory(*encoderParams\Parameter[i]\guid, ?GUID_EncoderImageItems, SizeOf(GUID))
            t1$ = "image items"
          ElseIf CompareMemory(*encoderParams\Parameter[i]\guid, ?GUID_EncoderSaveAsCMYK, SizeOf(GUID))
            t1$ = "save as CMYK"
          EndIf
          Debug "        The categeory is '" + t1$ + "'."
          t1$ = "unknown"
          Select *encoderParams\Parameter[i]\Type
            Case #EncoderParameterValueTypeByte
              t1$ = "byte"
            Case #EncoderParameterValueTypeASCII
              t1$ = "ascii"
            Case #EncoderParameterValueTypeShort 
              t1$ = "short"
            Case #EncoderParameterValueTypeLong
              t1$ = "long"
            Case #EncoderParameterValueTypeRational
              t1$ = "rational"
            Case #EncoderParameterValueTypeLongRange 
              t1$ = "long range"
            Case #EncoderParameterValueTypeUndefined 
              t1$ = "undefined"
            Case #EncoderParameterValueTypeRationalRange 
              t1$ = "rational range"
            Case #EncoderParameterValueTypePointer
              t1$ = "pointer"
          EndSelect
          Debug "        The data type is '" + t1$ + "'."
          Debug "        The number of possible values is " + Str(*encoderParams\Parameter[i]\NumberOfValues)
        Next
        FreeMemory(*encoderParams)    
      EndIf
    EndIf
    GdipDisposeImage(image)
  EndIf
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
;-GUIDs.
  DataSection
    ;Encoder parameters.
      GUID_EncoderCompression:
        Data.l $E09D739D
        Data.w $CCD4, $44EE
        Data.b $8E, $BA, $3F, $BF, $8B, $E4, $FC, $58
      GUID_EncoderColorDepth:
        Data.l $66087055
        Data.w $AD66, $4C7C
        Data.b $9A, $18, $38, $A2, $31, $0B, $83, $37
      GUID_EncoderScanMethod:
        Data.l $3A4E2661
        Data.w $3109, $4E56
        Data.b $85, $36, $42, $C1, $56, $E7, $DC, $FA
      GUID_EncoderVersion:
        Data.l $24D18C76
        Data.w $814A, $41A4
        Data.b $BF, $53, $1C, $21, $9C, $CC, $F7, $97
      GUID_EncoderRenderMethod:
        Data.l $6D42C53A
        Data.w $229A, $4825
        Data.b $8B, $B7, $5C, $99, $E2, $B9, $A8, $B8
      GUID_EncoderQuality:
        Data.l $1D5BE4B5
        Data.w $FA4A, $452D
        Data.b $9C, $DD, $5D, $B3, $51, $05, $E7, $EB
      GUID_EncoderTransformation:
        Data.l $8D0EB2D1
        Data.w $A58E, $4EA8
        Data.b $AA, $14, $10, $80, $74, $B7, $B6, $F9
      GUID_EncoderLuminanceTable:
        Data.l $EDB33BCE
        Data.w $0266, $4A77
        Data.b $B9, $04, $27, $21, $60, $99, $E7, $17
      GUID_EncoderChrominanceTable:
        Data.l $F2E455DC
        Data.w $09B3, $4316
        Data.b $82, $60, $67, $6A, $DA, $32, $48, $1C
      GUID_EncoderSaveFlag:
        Data.l $292266FC
        Data.w $AC40, $47BF
        Data.b $8C, $FC, $A8, $5B, $89, $A6, $55, $DE
      GUID_EncoderColorSpace:
        Data.l $AE7A62A0
        Data.w $EE2C,$49D8
        Data.b $9D,$7,$1B,$A8,$A9,$27,$59,$6E
      GUID_EncoderImageItems:
        Data.l $63875E13
        Data.w $1F1D,$45AB
        Data.b $91, $95, $A2, $9B, $60, $66, $A6, $50
      GUID_EncoderSaveAsCMYK:
        Data.l $A219BBC9
        Data.w $A9D, $4005
        Data.b $A3, $EE, $3A, $42, $1B, $8B, $B0, $6C
  EndDataSection
;/////////////////////////////////////////////////////////////////////////////////

DisableExplicit

DisplayEncoderParameters()

; IDE Options = PureBasic 4.51 (Windows - x86)
; ExecutableFormat = Shared Dll
; CursorPosition = 152
; FirstLine = 133
; Folding = -
; Markers = 144
; EnableXP
; Executable = nxReportU.dll