﻿EnableExplicit

CompilerIf Defined(INCLUDE_GDIPLUS, #PB_Constant)=0
#INCLUDE_GDIPLUS=1
;/////////////////////////////////////////////////////////////////////////////////
;***GDI+ wrapper file***  - Version 1.0.
;=======================
;
;©nxSoftware.com 2010.
;=====================
;   Stephen Rodriguez (srod)
;   Created with Purebasic 4.5 for Windows.
;   With thanks to Flype and SFSxOI for their gdiPlus includes.
;
;   Platforms:  Windows XP onwards (x86 and x64).
;   GDI+ 1.0.
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
;NOTES :
;
;   i)    This OOP wrapper wraps up some of the core functionality of the GdiPlus library into convenient classes.
;
;   ii)   Encoder CLSIDs have been 'hard coded' as opposed to us enumerating the codecs installed everytime we save an image etc.
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
;-HEADER FILE.
  XIncludeFile #PB_Compiler_FilePath + "gdiPlus_Header.pbi"
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
;-CONSTANTS (Non GDI+).

  Enumeration ;Image formats.
    #GDIPLUS_BMP                      = 1 ;Save format.
    #GDIPLUS_JPEG                         ;Save format.
    #GDIPLUS_JPG = #GDIPLUS_JPEG          ;Save format.
    #GDIPLUS_GIF                          ;Save format.
    #GDIPLUS_TIFF                         ;Save format.
    #GDIPLUS_PNG                          ;Save format.
    #GDIPLUS_MEMORYBMP                    ;Not a save format.
    #GDIPLUS_EMF                          ;Not a save format.
    #GDIPLUS_WMF                          ;Not a save format.
    #GDIPLUS_EXIF                         ;Not a save format.
    #GDIPLUS_PHOTOCD                      ;Not a save format.
    #GDIPLUS_FLASHPIX                     ;Not a save format.
    #GDIPLUS_FLASHICON                    ;Not a save format.
    #GDIPLUS_UNDEFINED                    ;Not a save format.
  EndEnumeration

  Enumeration ;Encoder parameter categories.
    #GDIPLUS_ENCODERCOMPRESSION       = 1
    #GDIPLUS_ENCODERCOLORDEPTH
    #GDIPLUS_ENCODERSCANMETHOD
    #GDIPLUS_ENCODERVERSION
    #GDIPLUS_ENCODERRENDERMETHOD
    #GDIPLUS_ENCODERQUALITY
    #GDIPLUS_ENCODERTRANSFORMATION
    #GDIPLUS_ENCODERLUMINANCETABLE
    #GDIPLUS_ENCODERCHROMINANCETABLE
    #GDIPLUS_ENCODERSAVEFLAG
    #GDIPLUS_ENCODERCOLORSPACE
    #GDIPLUS_ENCODERIMAGEITEMS
    #GDIPLUS_ENCODERSSAVEASCMYK
  EndEnumeration

  Enumeration ;Multi-frame dimension IDs.
    #GDIPLUS_FRAMEDIMENSIONTIME       = 1
    #GDIPLUS_FRAMEDIMENSIONRESOLUTION
    #GDIPLUS_FRAMEDIMENSIONPAGE
  EndEnumeration

;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
;-STRUCTURES (Non GDI+).

  ;The following is used as the basis for all class templates to avoid circular references between different classes.
  ;Individual classes will use the following or will extend it.
    Structure _gdiPlus_GenericObject_Template
      *vTable.i
      object.i
    EndStructure
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
;-MACROS.

  ;ARGB macros.
    Macro MakeARGB(a, r, g, b)
      b | (g<<8) | (r<<16) | (a<<24)
    EndMacro

    Macro ARGB_Alpha(argb)
      (argb>>24)&$FF    
    EndMacro

    Macro ARGB_Red(argb)
      (argb>>16)&$FF    
    EndMacro

    Macro ARGB_Green(argb)
      (argb>>8)&$FF    
    EndMacro

    Macro ARGB_Blue(argb)
      argb&$FF    
    EndMacro

    Macro ARGBToGDIColor(argb)
      (argb & $FF00FF00) | (argb&$FF)<<16 | (argb>>16&$FF)
    EndMacro

    Macro GDIColorToARGB(gdiColor)
      (gdiColor & $FF00FF00) | (gdiColor&$FF)<<16 | (gdiColor>>16&$FF)
    EndMacro
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
;-BASE CLASS. 

  ;The following interface will be inherited by those classes which wrap some kind of GDI+ object. E.g. the image class wraps
  ;a GDI+ image object etc. There is only one method and it can be used to retrieve the GDI+ handle of the underlying object.
    Interface gdiPlus_BaseClass
      GetGdiPlusHandle.i()
    EndInterface
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
;-CLASSES.
  Declare.i gdiPlus_BaseClass_GetGdiPlusHandle(*this._gdiPlus_GenericObject_Template) ;Base-class method.

  XIncludeFile #PB_Compiler_FilePath + "gdiPlus_PointIClass.pbi"
  XIncludeFile #PB_Compiler_FilePath + "gdiPlus_PointFClass.pbi"
  XIncludeFile #PB_Compiler_FilePath + "gdiPlus_RectIClass.pbi"
  XIncludeFile #PB_Compiler_FilePath + "gdiPlus_RectFClass.pbi"
  XIncludeFile #PB_Compiler_FilePath + "gdiPlus_BitmapDataClass.pbi"
  XIncludeFile #PB_Compiler_FilePath + "gdiPlus_PropertyItemClass.pbi"
  XIncludeFile #PB_Compiler_FilePath + "gdiPlus_EncoderParametersClass.pbi"
  XIncludeFile #PB_Compiler_FilePath + "gdiPlus_ImageClass.pbi"
  XIncludeFile #PB_Compiler_FilePath + "gdiPlus_FontFamilyClass.pbi"
  XIncludeFile #PB_Compiler_FilePath + "gdiPlus_FontCollectionClass.pbi"
  XIncludeFile #PB_Compiler_FilePath + "gdiPlus_FontClass.pbi"
  XIncludeFile #PB_Compiler_FilePath + "gdiPlus_BrushClass.pbi"
  XIncludeFile #PB_Compiler_FilePath + "gdiPlus_HatchBrushClass.pbi"
  XIncludeFile #PB_Compiler_FilePath + "gdiPlus_MatrixClass.pbi"
  XIncludeFile #PB_Compiler_FilePath + "gdiPlus_LinearGradientBrushClass.pbi"
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
;-GLOBALS.
    Global g_GdiPlus_Token
;/////////////////////////////////////////////////////////////////////////////////


;-FUNCTIONS.

;/////////////////////////////////////////////////////////////////////////////////
;Call the following function to initialise GdiPlus. It must not be called in a DLL entry-point function.
;Returns a gdiPlus status code (0 for okay).
Procedure.i gdiPlus_Init()
  Protected input.GdiplusStartupInput
  input\GdiPlusVersion = 1
  ProcedureReturn GdiplusStartup(@g_GdiPlus_Token, input)
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
;Call the following function to shutdown GdiPlus. Must be called after a successful call to gdiPlus_Init().
Procedure gdiPlus_Free()
  GdiplusShutdown(g_GdiPlus_Token)
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;-BASE CLASS METHODS.

;/////////////////////////////////////////////////////////////////////////////////
Procedure.i gdiPlus_BaseClass_GetGdiPlusHandle(*this._gdiPlus_GenericObject_Template)
  ProcedureReturn *this\object
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////

CompilerEndIf

DisableExplicit

; IDE Options = PureBasic 4.51 (Windows - x86)
; ExecutableFormat = Shared Dll
; CursorPosition = 140
; FirstLine = 120
; Folding = h-
; Markers = 186
; EnableUnicode
; EnableXP
; Executable = nxReportU.dll