﻿;/////////////////////////////////////////////////////////////////////////////////
;***GDI+ wrapper file***
;=======================
;
;EncoderParameters class.
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
;-INTERFACE.

  ;All methods return a gdiPlus status code (0 for okay) unless otherwise stated.
  Interface gdiPlus_EncoderParameters
    Destroy()
    AddParameter.i(category, valueType, value, numValues=1) ;category is an encoder parameter constant, e.g. #GDIPLUS_ENCODERCOMPRESSION.
                                                            ;valueType is an encoder parameter value type constant, e.g. #EncoderParameterValueTypeLong.
                                                            ;value is a pointer to an array (usually just a single value) of 'numValues' elements of type 'valueType'.
                                                            ;numValues is the number of elements in the aforementioned array.
  EndInterface
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
;-CLASS TEMPLATE.

  Structure _gdiPlus_EncoderParameters_Template
    *vTable.i
    ;Member fields.
      encoderParameters.EncoderParameters
  EndStructure
;/////////////////////////////////////////////////////////////////////////////////


;-CONSTRUCTORS.

;/////////////////////////////////////////////////////////////////////////////////
;Returns, if successful, a gdiPlus_EncoderParameters object pointer.
Procedure.i gdiPlus_CreateEncoderParameters()
  Protected *encoder._gdiPlus_EncoderParameters_Template
  *encoder = AllocateMemory(SizeOf(_gdiPlus_EncoderParameters_Template))
  If *encoder
    *encoder\vTable = ?_gdiPlus_EncoderParameters_Template_VT
  EndIf
  ProcedureReturn *encoder
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////



;-METHODS.

;/////////////////////////////////////////////////////////////////////////////////
Procedure gdiPlus_EncoderParametersClass_Destroy(*this._gdiPlus_EncoderParameters_Template)
  FreeMemory(*this)
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
Procedure.i gdiPlus_EncoderParametersClass_AddParameter(*this._gdiPlus_EncoderParameters_Template, category, valueType, value, numValues=1)
  Protected result = #Ok, guidPtr
  If *this\encoderParameters\Count < 13 ;The maxium number of parameters defined.
    If valueType >= #EncoderParameterValueTypeByte And valueType <= #EncoderParameterValueTypePointer And value
      ;Sort out the category GUID.
        Select category
          Case #GDIPLUS_ENCODERCOMPRESSION
            guidPtr = ?GUID_EncoderCompression
          Case #GDIPLUS_ENCODERCOLORDEPTH
            guidPtr = ?GUID_EncoderColorDepth
          Case #GDIPLUS_ENCODERSCANMETHOD
            guidPtr = ?GUID_EncoderScanMethod
          Case #GDIPLUS_ENCODERVERSION
            guidPtr = ?GUID_EncoderVersion
          Case #GDIPLUS_ENCODERRENDERMETHOD
            guidPtr = ?GUID_EncoderRenderMethod
          Case #GDIPLUS_ENCODERQUALITY
            guidPtr = ?GUID_EncoderQuality
          Case #GDIPLUS_ENCODERTRANSFORMATION
            guidPtr = ?GUID_EncoderTransformation
          Case #GDIPLUS_ENCODERLUMINANCETABLE
            guidPtr = ?GUID_EncoderLuminanceTable
          Case #GDIPLUS_ENCODERCHROMINANCETABLE
            guidPtr = ?GUID_EncoderChrominanceTable
          Case #GDIPLUS_ENCODERSAVEFLAG
            guidPtr = ?GUID_EncoderSaveFlag
          Case #GDIPLUS_ENCODERCOLORSPACE
            guidPtr = ?GUID_EncoderColorSpace
          Case #GDIPLUS_ENCODERIMAGEITEMS
            guidPtr = ?GUID_EncoderImageItems
          Case #GDIPLUS_ENCODERSSAVEASCMYK
            guidPtr = ?GUID_EncoderSaveAsCMYK
        EndSelect
        If guidPtr
          CopyMemory(guidPtr, *this\encoderParameters\Parameter[*this\encoderParameters\Count]\guid, SizeOf(GUID))
          *this\encoderParameters\Parameter[*this\encoderParameters\Count]\NumberOfValues = numValues
          *this\encoderParameters\Parameter[*this\encoderParameters\Count]\Type = valueType
          *this\encoderParameters\Parameter[*this\encoderParameters\Count]\Value = value
          *this\encoderParameters\Count + 1
        Else
          result = #InvalidParameter    
        EndIf
    Else
      result = #InvalidParameter    
    EndIf
  Else
    result = #InsufficientBuffer
  EndIf
  ProcedureReturn result
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////



;/////////////////////////////////////////////////////////////////////////////////
;-VIRTUAL TABLE.
DataSection
  _gdiPlus_EncoderParameters_Template_VT:
    Data.i @gdiPlus_EncoderParametersClass_Destroy()
    Data.i @gdiPlus_EncoderParametersClass_AddParameter()
EndDataSection
;/////////////////////////////////////////////////////////////////////////////////

; IDE Options = PureBasic 4.51 (Windows - x86)
; ExecutableFormat = Shared Dll
; CursorPosition = 93
; FirstLine = 72
; Folding = -
; Markers = 5
; EnableUnicode
; EnableXP
; Executable = nxReportU.dll