﻿;/////////////////////////////////////////////////////////////////////////////////
;***GDI+ wrapper file***
;=======================
;
;Font class.
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
;-INTERFACE.

  ;All methods return a gdiPlus status code (0 for okay) unless otherwise stated.
  Interface gdiPlus_Font Extends gdiPlus_BaseClass
    Destroy()
    Clone.i()                                                           ;Returns, if successful, a new gdiPlus_Font object containing an exact copy of the original object.
    GetFamily.i()                                                       ;Returns a new gdiPlus_FontFamily object which should be destroyed when no longer required.
    GetHeightFromGraphics.f(*graphics._gdiPlus_GenericObject_Template)  ;Returns the line-spacing of the font in the current units of the specified graphics object.
    GetHeightGivenDPI.f(dpi.f)                                          ;Returns the line-spacing of the font in pixels. If the font unit
                                                                        ;is set to anything other than UnitPixel, the height, in pixels, is calculated using the specified vertical resolution. 
    GetLogFont.i(*graphics._gdiPlus_GenericObject_Template, *logfont.LOGFONT)
                                                                        ;Fills out a LOGFONT structure to get the attributes of the font object.
    GetSize.f()                                                         ;Returns the em font size in the units of the font object.
    GetStyle.i()                                                        ;Returns a combination of FontStyle constants, e.g. #FontStyleRegular.
    GetUnit.i()                                                         ;Returns a Unit constant, e.g. #UnitPoint.
  EndInterface
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
;-CLASS TEMPLATE.

  Macro _gdiPlus_Font_Template
    _gdiPlus_GenericObject_Template
  EndMacro
;/////////////////////////////////////////////////////////////////////////////////


;-CONSTRUCTORS.

;/////////////////////////////////////////////////////////////////////////////////
;Returns, if successful, a gdiPlus_Font object pointer.
Procedure.i gdiPlus_CreateFont(*fontFamily._gdiPlus_GenericObject_Template, emSize.f, fontStyle=#FontStyleRegular, unit=#UnitPoint)
  Protected *font._gdiPlus_Font_Template
  If *fontFamily
    *font = AllocateMemory(SizeOf(_gdiPlus_Font_Template))
    If *font
      *font\vTable = ?_gdiPlus_Font_Template_VT
      If GdipCreateFont(*fontFamily\object, emSize, fontStyle, unit, @*font\object) <> #ok
        FreeMemory(*font)
        *font = 0
      EndIf
    EndIf
  EndIf
  ProcedureReturn *font
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
;Returns, if successful, a gdiPlus_Font object pointer.
;The DC must have a suitable font selected into it.
Procedure.i gdiPlus_FontFromDC(hdc)
  Protected *font._gdiPlus_Font_Template
  *font = AllocateMemory(SizeOf(_gdiPlus_Font_Template))
  If *font
    *font\vTable = ?_gdiPlus_Font_Template_VT
    If GdipCreateFontFromDC(hdc, @*font\object) <> #ok
      FreeMemory(*font)
      *font = 0
    EndIf
  EndIf
  ProcedureReturn *font
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
;Returns, if successful, a gdiPlus_Font object pointer.
Procedure.i gdiPlus_FontFromLogFont(hdc, *lf.LOGFONT)
  Protected *font._gdiPlus_Font_Template, result
  *font = AllocateMemory(SizeOf(_gdiPlus_Font_Template))
  If *font
    *font\vTable = ?_gdiPlus_Font_Template_VT
    CompilerIf #PB_Compiler_Unicode
      result = GdipCreateFontFromLogfontW(hdc, *lf, @*font\object)
    CompilerElse
      result = GdipCreateFontFromLogfontA(hdc, *lf, @*font\object)
    CompilerEndIf
    If result <> #ok
      FreeMemory(*font)
      *font = 0
    EndIf
  EndIf
  ProcedureReturn *font
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;-METHODS.

;/////////////////////////////////////////////////////////////////////////////////
Procedure gdiPlus_FontClass_Destroy(*this._gdiPlus_Font_Template)
  GdipDeleteFont(*this\object)
  FreeMemory(*this)
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
Procedure.i gdiPlus_FontClass_Clone(*this._gdiPlus_Font_Template)
  Protected *font._gdiPlus_Font_Template
  *font = AllocateMemory(SizeOf(_gdiPlus_Font_Template))
  If *font
    *font\vTable = ?_gdiPlus_Font_Template_VT
    If GdipCloneFont(*this\object, @*font\object) <> #ok
      FreeMemory(*font)
      *font = 0 
    EndIf
  EndIf
  ProcedureReturn *font
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
Procedure.i gdiPlus_FontClass_GetFamily(*this._gdiPlus_Font_Template)
  Protected *fontFamily._gdiPlus_FontFamily_Template
  *fontFamily = AllocateMemory(SizeOf(_gdiPlus_FontFamily_Template))
  If *fontFamily
    *fontFamily\vTable = ?_gdiPlus_FontFamily_Template_VT
    If GdipGetFamily(*this\object, @*fontFamily\object) <> #ok
      FreeMemory(*fontFamily)
      *fontFamily = 0 
    EndIf
  EndIf
  ProcedureReturn *fontFamily
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
Procedure.f gdiPlus_FontClass_GetHeightFromGraphics(*this._gdiPlus_Font_Template, *graphics._gdiPlus_GenericObject_Template)
  Protected result.f
  If *graphics
    GdipGetFontHeight(*this\object, *graphics\object, @result)
  EndIf
  ProcedureReturn result
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
Procedure.f gdiPlus_FontClass_GetHeightGivenDPI(*this._gdiPlus_Font_Template, dpi.f)
  Protected result.f
  GdipGetFontHeightGivenDPI(*this\object, dpi, @result)
  ProcedureReturn result
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
Procedure.i gdiPlus_FontClass_GetLogFont(*this._gdiPlus_Font_Template, *graphics._gdiPlus_GenericObject_Template, *logfont.LOGFONT)
  Protected result
  If *graphics
    CompilerIf #PB_Compiler_Unicode
      result = GdipGetLogFontW(*this\object, *graphics\object, *logfont)  
    CompilerElse
      result = GdipGetLogFontA(*this\object, *graphics\object, *logfont)  
    CompilerEndIf
  Else
    result = #InvalidParameter
  EndIf
  ProcedureReturn result
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
Procedure.f gdiPlus_FontClass_GetSize(*this._gdiPlus_Font_Template)
  Protected result.f
  GdipGetFontSize(*this\object, @result)
  ProcedureReturn result
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
Procedure.i gdiPlus_FontClass_GetStyle(*this._gdiPlus_Font_Template)
  Protected result
  GdipGetFontStyle(*this\object, @result)
  ProcedureReturn result
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
Procedure.i gdiPlus_FontClass_GetUnit(*this._gdiPlus_Font_Template)
  Protected result
  GdipGetFontUnit(*this\object, @result)
  ProcedureReturn result
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
;-VIRTUAL TABLE.
DataSection
  _gdiPlus_Font_Template_VT:
    Data.i @gdiPlus_BaseClass_GetGdiPlusHandle()
    Data.i @gdiPlus_FontClass_Destroy()
    Data.i @gdiPlus_FontClass_Clone()
    Data.i @gdiPlus_FontClass_GetFamily()
    Data.i @gdiPlus_FontClass_GetHeightFromGraphics()
    Data.i @gdiPlus_FontClass_GetHeightGivenDPI()
    Data.i @gdiPlus_FontClass_GetLogFont()
    Data.i @gdiPlus_FontClass_GetSize()
    Data.i @gdiPlus_FontClass_GetStyle()
    Data.i @gdiPlus_FontClass_GetUnit()
EndDataSection
;/////////////////////////////////////////////////////////////////////////////////

; IDE Options = PureBasic 4.51 (Windows - x86)
; ExecutableFormat = Shared Dll
; CursorPosition = 198
; FirstLine = 183
; Folding = ---
; Markers = 5
; EnableUnicode
; EnableXP
; Executable = nxReportU.dll