﻿;/////////////////////////////////////////////////////////////////////////////////
;***GDI+ wrapper file***
;=======================
;
;FontCollection class.
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
;-INTERFACE.

  ;All methods return a gdiPlus status code (0 for okay) unless otherwise stated.
  Interface gdiPlus_FontCollection Extends gdiPlus_BaseClass
    Destroy()
    AddFontFile.i(fileName$)                    ;For private collections only.
    AddMemoryFont.i(*memory, length)            ;For private collections only.
    DestroyFamilies(*buffer.INTEGER)            ;Use after a successful invokation of the \GetFamilies() method.
                                                ;*buffer must hold the same value as the corresponding parameter to the \GetFamilies() method.
    GetFamilies.i(numSought, *buffer.INTEGER)   ;Returns the number of font families found.
    GetFamilyCount.i()                          ;Returns the number of font families contained in this font collection.
  EndInterface
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
;-CLASS TEMPLATE.

  Structure _gdiPlus_FontCollection_Template Extends _gdiPlus_GenericObject_Template
    blnIsPrivateFontCollection.i
  EndStructure
;/////////////////////////////////////////////////////////////////////////////////


;-CONSTRUCTORS.

;/////////////////////////////////////////////////////////////////////////////////
;Returns, if successful, a gdiPlus_FontCollection object pointer.
Procedure.i gdiPlus_CreateInstalledFontCollection()
  Protected *fontCollection._gdiPlus_FontCollection_Template
  *fontCollection = AllocateMemory(SizeOf(_gdiPlus_FontCollection_Template))
  If *fontCollection
    *fontCollection\vTable = ?_gdiPlus_FontCollection_Template_VT
    *fontCollection\blnIsPrivateFontCollection = #False
    If GdipNewInstalledFontCollection(@*fontCollection\object) <> #ok
      FreeMemory(*fontCollection)
      *fontCollection = 0
    EndIf
  EndIf
  ProcedureReturn *fontCollection
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
;Returns, if successful, a gdiPlus_FontCollection object pointer.
Procedure.i gdiPlus_CreatePrivateFontCollection()
  Protected *fontCollection._gdiPlus_FontCollection_Template
  *fontCollection = AllocateMemory(SizeOf(_gdiPlus_FontCollection_Template))
  If *fontCollection
    *fontCollection\vTable = ?_gdiPlus_FontCollection_Template_VT
    *fontCollection\blnIsPrivateFontCollection = #True
    If GdipNewPrivateFontCollection(@*fontCollection\object) <> #ok
      FreeMemory(*fontCollection)
      *fontCollection = 0
    EndIf
  EndIf
  ProcedureReturn *fontCollection
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;-METHODS.

;/////////////////////////////////////////////////////////////////////////////////
Procedure gdiPlus_FontCollectionClass_Destroy(*this._gdiPlus_FontCollection_Template)
  ;Destroy the GDI+ collection object if it is a private collection.
    If *this\blnIsPrivateFontCollection
      GdipDeletePrivateFontCollection(@*this\object)  
    EndIf
  FreeMemory(*this)
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
Procedure.i gdiPlus_FontCollectionClass_AddFontFile(*this._gdiPlus_FontCollection_Template, fileName$)
  Protected result
  result = GdipPrivateAddFontFile(*this\object, fileName$)
  ProcedureReturn result
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
Procedure.i gdiPlus_FontCollectionClass_AddMemoryFont(*this._gdiPlus_FontCollection_Template, *memory, length)
  Protected result
  result = GdipPrivateAddMemoryFont(*this\object, *memory, length)
  ProcedureReturn result
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
Procedure gdiPlus_FontCollectionClass_DestroyFamilies(*this._gdiPlus_FontCollection_Template, *buffer.INTEGER)
  If *buffer And *buffer\i
    FreeMemory(*buffer\i)
  EndIf
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
Procedure.i gdiPlus_FontCollectionClass_GetFamilies(*this._gdiPlus_FontCollection_Template, numSought, *buffer.INTEGER)
  Protected result, i, t1, *fontFamily._gdiPlus_FontFamily_Template
  GdipGetFontCollectionFamilyList(*this\object, numSought, *buffer, @result)
  If result
    *fontFamily = AllocateMemory(result * SizeOf(_gdiPlus_FontFamily_Template))
    If *fontFamily
      ;We must convert each GDI+ object returned to a gdiPlus_FontFamily object.
        For i = 0 To result-1
          t1 = *buffer\i
          *buffer\i = *fontFamily
          With *fontFamily
            \vTable = ?_gdiPlus_FontFamily_Template_VT          
            \object = t1
          EndWith
          *fontFamily + SizeOf(_gdiPlus_FontFamily_Template)
          *buffer + SizeOf(INTEGER)
        Next
    EndIf
  EndIf
  ProcedureReturn result
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
Procedure.i gdiPlus_FontCollectionClass_GetFamilyCount(*this._gdiPlus_FontCollection_Template)
  Protected result
  GdipGetFontCollectionFamilyCount(*this\object, @result)
  ProcedureReturn result
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
;-VIRTUAL TABLE.
DataSection
  _gdiPlus_FontCollection_Template_VT:
    Data.i @gdiPlus_BaseClass_GetGdiPlusHandle()
    Data.i @gdiPlus_FontCollectionClass_Destroy()
    Data.i @gdiPlus_FontCollectionClass_AddFontFile()
    Data.i @gdiPlus_FontCollectionClass_AddMemoryFont()
    Data.i @gdiPlus_FontCollectionClass_DestroyFamilies()
    Data.i @gdiPlus_FontCollectionClass_GetFamilies()
    Data.i @gdiPlus_FontCollectionClass_GetFamilyCount()
EndDataSection
;/////////////////////////////////////////////////////////////////////////////////

; IDE Options = PureBasic 4.51 (Windows - x86)
; ExecutableFormat = Shared Dll
; CursorPosition = 152
; FirstLine = 120
; Folding = --
; Markers = 5
; EnableUnicode
; EnableXP
; Executable = nxReportU.dll