﻿;/////////////////////////////////////////////////////////////////////////////////
;***GDI+ wrapper file***
;=======================
;
;HatchBrush class.
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
;-INTERFACE.

  ;All methods return a gdiPlus status code (0 for okay) unless otherwise stated.
  Interface gdiPlus_HatchBrush Extends gdiPlus_Brush
    Clone.i()                                                 ;Returns, if successful, a new gdiPlus_HatchBrush object containing an exact copy of the original object.
    GetBackgroundColor.i()                                    ;Returns the back color in ARGB format.
    GetForegroundColor.i()                                    ;Returns the fore color in ARGB format.
    GetHatchStyle.i()                                         ;Returns one of the HatchStyle constants, e.g. #HatchStyleHorizontal.
  EndInterface
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
;-CLASS TEMPLATE.

  Macro _gdiPlus_HatchBrush_Template
    _gdiPlus_GenericObject_Template
  EndMacro
;/////////////////////////////////////////////////////////////////////////////////


;-CONSTRUCTORS.

;/////////////////////////////////////////////////////////////////////////////////
;Returns, if successful, a gdiPlus_HatchBrush object pointer.
Procedure.i gdiPlus_CreateHatchBrush(hatchStyle, foreColor, backColor)
  Protected *brush._gdiPlus_HatchBrush_Template
  *brush = AllocateMemory(SizeOf(_gdiPlus_HatchBrush_Template))
  If *brush
    *brush\vTable = ?_gdiPlus_HatchBrush_Template_VT
    If GdipCreateHatchBrush(hatchStyle, foreColor, BackColor, @*brush\object) <> #Ok
      FreeMemory(*brush)
      *brush = 0
    EndIf
  EndIf
  ProcedureReturn *brush
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;-METHODS.

;/////////////////////////////////////////////////////////////////////////////////
Procedure.i gdiPlus_HatchBrushClass_Clone(*this._gdiPlus_HatchBrush_Template)
  Protected *brush._gdiPlus_HatchBrush_Template, t1
  If GdipCloneBrush(*this\object, @t1) = #ok
    *brush = AllocateMemory(SizeOf(_gdiPlus_HatchBrush_Template))
    If *brush
      *brush\vTable = ?_gdiPlus_HatchBrush_Template_VT
      *brush\object = t1
    Else
      GdipDeleteBrush(t1)
    EndIf
  EndIf
  ProcedureReturn *brush
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
Procedure.i gdiPlus_HatchBrushClass_GetBackgroundColor(*this._gdiPlus_HatchBrush_Template)
  Protected result
  GdipGetHatchBackgroundColor(*this\object, @result)
  ProcedureReturn result
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
Procedure.i gdiPlus_HatchBrushClass_GetForegroundColor(*this._gdiPlus_HatchBrush_Template)
  Protected result
  GdipGetHatchForegroundColor(*this\object, @result)
  ProcedureReturn result
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
Procedure.i gdiPlus_HatchBrushClass_GetHatchStyle(*this._gdiPlus_HatchBrush_Template)
  Protected result
  GdipGetHatchStyle(*this\object, @result)
  ProcedureReturn result
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
;-VIRTUAL TABLE.
DataSection
  _gdiPlus_HatchBrush_Template_VT:
    Data.i @gdiPlus_BaseClass_GetGdiPlusHandle()
    Data.i @gdiPlus_BrushClass_Destroy()
    Data.i @gdiPlus_BrushClass_GetType()
    Data.i @gdiPlus_HatchBrushClass_Clone()
    Data.i @gdiPlus_HatchBrushClass_GetBackgroundColor()
    Data.i @gdiPlus_HatchBrushClass_GetForegroundColor()
    Data.i @gdiPlus_HatchBrushClass_GetHatchStyle()
EndDataSection
;/////////////////////////////////////////////////////////////////////////////////

; IDE Options = PureBasic 4.51 (Windows - x86)
; ExecutableFormat = Shared Dll
; CursorPosition = 13
; Folding = --
; Markers = 5
; EnableUnicode
; EnableXP
; Executable = nxReportU.dll