﻿;/////////////////////////////////////////////////////////////////////////////////
;***GDI+ wrapper file***
;=======================
;
;Image class.
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
;-INTERFACE.

  ;All methods return a gdiPlus status code (0 for okay) unless otherwise stated.
  Interface gdiPlus_Image Extends gdiPlus_BaseClass
    Destroy()
    Clone.i()                                                                   ;Returns, if successful, a new gdiPlus_Image object containing an exact copy of the original image.
    CloneAreaF.i(x.f, y.f, width.f, height.f, format)                           ;Returns, if successful, a new gdiPlus_Image object.
    CloneAreaI.i(x, y, width, height, format)                                   ;Returns, if successful, a new gdiPlus_Image object.
    GetBounds.i(*srcRect.RectF, *srcUnit.INTEGER)
    GetFlags.i()                                                                ;Returns a combination of Image flags, e.g. #ImageFlagsHasAlpha etc.
    GetHBITMAP.i(backColor)                                                     ;Returns, if successful, a gdi bitmap. The backColor parameter is ignored if the bitmap is totally opaque. 
    GetHeight.i()                                                               ;Returns the image height.
    GetHICON.i()                                                                ;Returns, if successful, a icon handle.
    GetHorizontalResolution.f()                                                 ;Returns the resolution in dpi.
    GetPalette.i(*palette.ColorPalette, size)
    GetPaletteSize.i()                                                          ;Returns the size, in bytes, of the image's palette. This will always be at least 12 bytes
                                                                                ;because the GDI+ ColorPalette structure always includes at least 1 ARGB entry.
    GetPixel.i(x, y)                                                            ;Returns the pixel color in 32-bit ARGB format.
    GetPixelFormat.i()                                                          ;Returns a pixel format constant, e.g. #PixelFormat32bppARGB.
    GetRawFormat.i()                                                            ;Returns a image format constant, e.g. #GDIPLUS_BMP.
    GetVerticalResolution.f()                                                 ;Returns the resolution in dpi.
    GetWidth.i()                                                                ;Returns the image width.
    RotateFlip.i(rfType)
    Save.i(fileName$, type, *params._gdiPlus_EncoderParameters_Template=0)      ;Type = one of the save image format constants : #GDIPLUS_BITMAP etc.
    SaveToMemory.i(type, *size.INTEGER=0, *params._gdiPlus_EncoderParameters_Template=0)
                                                                                ;*size points to a buffer which receives the number of bytes in the saved image.
                                                                                ;Returns, if successful, the address of a buffer containing the image data. Use FreeMemory() when finished.
    SetPalette.i(*palette.ColorPalette)                                         ;Doesn't seem possible to set the palette of an image in which a palette has already been set.
    SetPixel.i(x, y, ARGBColor)
    SetResolution.i(xdpi.f, ydpi.f)
    ;Locking / unlocking pixel bits. For use with retrieving and/or setting scan lines etc. Much like GetDIBits_() and so on.
      LockBits.i(*rc.RECT, flags, pixelFormat, *lockedBitmapData.BitmapData)    ;flags = a combination of the 'Image lock mode' constants, e.g. #ImageLockModeUserInputBuf.
                                                                                ;pixelFormat = #PixelFormat32bppARGB etc.
                                                                                ;*lockedBitmapData points to a BitmapData structure (see the BitmapData helper class) and use depends
                                                                                ;upon the flags parameter.
      UnlockBits.i(*lockedBitmapData.BitmapData)                                ;Call after using the \LockBits() method, passing the same *lockedBitmapData pointer.                                                                             
    ;Multi-page images.
      GetFrameCount.i(dimension)                                                ;Dimension is one of the multi-frame dimension IDs, e.g. #GDIPLUS_FRAMEDIMENSIONPAGE.
                                                                                ;Returns the number of frames in the specified dimension.
      SaveAdd.i(*params._gdiPlus_EncoderParameters_Template=0)                  ;Use to save the currently selected frame to the most recently saved image file (must be a multi-image file).
      SaveAddImage.i(*newImage, *params._gdiPlus_EncoderParameters_Template=0)  ;Use to add a new image to the most recently saved image file (must be a multi-image file).
      SelectActiveFrame.i(dimension, index)                                     ;Dimension is one of the multi-frame dimension IDs, e.g. #GDIPLUS_FRAMEDIMENSIONPAGE.
                                                                                ;Index is 0-based.
    ;Properties.
      GetPropertyCount.i()                                                      ;Returns the number of properties stored in the image.
      GetPropertyIdList.i(numProperties, *buffer)
      GetPropertyItem.i(propId, propSize, *propItem.PropertyItem)
      GetPropertyItemSize.i(propId)                                             ;Returns a Image property ID Tags constant, e.g. #PropertyTagExifIFD .
      RemovePropertyItem.i(propId)
      SetPropertyItem(*item.PropertyItem)
  EndInterface
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
;-CLASS TEMPLATE.

  Macro _gdiPlus_Image_Template
    _gdiPlus_GenericObject_Template
  EndMacro
;/////////////////////////////////////////////////////////////////////////////////


;-CONSTRUCTORS.

;/////////////////////////////////////////////////////////////////////////////////
;Returns, if successful, a gdiPlus_Image object pointer.
Procedure.i gdiPlus_CatchImage(*address, size)
  Protected *image._gdiPlus_Image_Template, hGlobal, *mem, stream.iStream
  If *address And size
    *image = AllocateMemory(SizeOf(_gdiPlus_Image_Template))
    If *image
      *image\vTable = ?_gdiPlus_Image_Template_VT
      ;Allocate a global memory object.
        hGlobal = GlobalAlloc_(#GMEM_MOVEABLE, size)
        If hGlobal
          *mem = GlobalLock_(hGlobal)
          If *mem
            CopyMemory(*address, *mem, size)
            GlobalUnlock_(hGlobal)
            If CreateStreamOnHGlobal_(hGlobal, #True, @stream) = #S_OK
              GdipLoadImageFromStream(stream, @*image\object)
              stream\Release() ;The hGlobal will be released when the stream object is destroyed after GdipDisposeImage() etc.
              If *image\object = 0
                Goto gdiPlus_CatchImage_L1
              EndIf
            Else
              Goto gdiPlus_CatchImage_L2
            EndIf          
          Else
gdiPlus_CatchImage_L2:
            GlobalFree_(hGlobal) 
            Goto gdiPlus_CatchImage_L1
          EndIf
        Else
gdiPlus_CatchImage_L1:
          FreeMemory(*image)
          *image = 0
        EndIf
    EndIf
  EndIf
  ProcedureReturn *image
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
;Returns, if successful, a gdiPlus_Image object pointer.
Procedure.i gdiPlus_CreateBitmap(width, height, pixelFormat=#PixelFormat24bppRGB)
  Protected *image._gdiPlus_Image_Template
  *image = AllocateMemory(SizeOf(_gdiPlus_Image_Template))
  If *image
    *image\vTable = ?_gdiPlus_Image_Template_VT
    If GdipCreateBitmapFromScan0(width, height, 0, pixelFormat, 0, @*image\object) <> #Ok
      FreeMemory(*image)
      *image = 0
    EndIf
  EndIf
  ProcedureReturn *image
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
;Returns, if successful, a gdiPlus_Image object pointer.
Procedure.i gdiPlus_CreateBitmapFromBitmapInfo(*bitmapinfo.BITMAPINFO, *pxBits)
  Protected *image._gdiPlus_Image_Template
  *image = AllocateMemory(SizeOf(_gdiPlus_Image_Template))
  If *image
    *image\vTable = ?_gdiPlus_Image_Template_VT
    If GdipCreateBitmapFromGdiDib(*bitmapinfo, *pxBits, @*image\object) <> #Ok
      FreeMemory(*image)
      *image = 0
    EndIf
  EndIf
  ProcedureReturn *image
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
;Returns, if successful, a gdiPlus_Image object pointer.
Procedure.i gdiPlus_CreateBitmapFromGraphics(width, height, *graphics._gdiPlus_GenericObject_Template)
  Protected *image._gdiPlus_Image_Template
  If *graphics
    *image = AllocateMemory(SizeOf(_gdiPlus_Image_Template))
    If *image
      *image\vTable = ?_gdiPlus_Image_Template_VT
      If GdipCreateBitmapFromGraphics(width, height, *graphics\object, @*image\object) <> #Ok
        FreeMemory(*image)
        *image = 0
      EndIf
    EndIf
  EndIf
  ProcedureReturn *image
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
;Returns, if successful, a gdiPlus_Image object pointer.
Procedure.i gdiPlus_CreateBitmapFromHBITMAP(hbm, hpal=0)
  Protected *image._gdiPlus_Image_Template
  *image = AllocateMemory(SizeOf(_gdiPlus_Image_Template))
  If *image
    *image\vTable = ?_gdiPlus_Image_Template_VT
    If GdipCreateBitmapFromHBITMAP(hbm, hpal, @*image\object) <> #Ok
      FreeMemory(*image)
      *image = 0
    EndIf
  EndIf
  ProcedureReturn *image
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
;Returns, if successful, a gdiPlus_Image object pointer.
;NOTE that GDI+ doesn't deal well with icons having alpha channels.
Procedure.i gdiPlus_CreateBitmapFromHICON(hicon)
  Protected *image._gdiPlus_Image_Template
  *image = AllocateMemory(SizeOf(_gdiPlus_Image_Template))
  If *image
    *image\vTable = ?_gdiPlus_Image_Template_VT
    If GdipCreateBitmapFromHICON(hicon, @*image\object) <> #Ok
      FreeMemory(*image)
      *image = 0
    EndIf
  EndIf
  ProcedureReturn *image
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
;Returns, if successful, a gdiPlus_Image object pointer.
Procedure.i gdiPlus_CreateBitmapFromResource(hInstance, bitmapName$)
  Protected *image._gdiPlus_Image_Template
  *image = AllocateMemory(SizeOf(_gdiPlus_Image_Template))
  If *image
    *image\vTable = ?_gdiPlus_Image_Template_VT
    If GdipCreateBitmapFromResource(hInstance, bitmapName$, @*image\object) <> #Ok
      FreeMemory(*image)
      *image = 0
    EndIf
  EndIf
  ProcedureReturn *image
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
;Returns, if successful, a gdiPlus_Image object pointer.
Procedure.i gdiPlus_CreateBitmapFromScan0(width, height, stride, pixelFormat, pixBytes)
  Protected *image._gdiPlus_Image_Template
  *image = AllocateMemory(SizeOf(_gdiPlus_Image_Template))
  If *image
    *image\vTable = ?_gdiPlus_Image_Template_VT
    If GdipCreateBitmapFromScan0(width, height, stride, pixelFormat, pixBytes, @*image\object) <> #Ok
      FreeMemory(*image)
      *image = 0
    EndIf
  EndIf
  ProcedureReturn *image
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
;Returns, if successful, a gdiPlus_Image object pointer.
;Note that the image file is locked by GDI+ until the image object is destroyed. If you wish to delete the image file before destroying the image object
;then copy the image file into a memory buffer and use gdiPlus_CatchImage() instead.
Procedure.i gdiPlus_LoadImage(fileName$)
  Protected *image._gdiPlus_Image_Template
  *image = AllocateMemory(SizeOf(_gdiPlus_Image_Template))
  If *image
    *image\vTable = ?_gdiPlus_Image_Template_VT
    If GdipLoadImageFromFile(fileName$, @*image\object) <> #Ok
      FreeMemory(*image)
      *image = 0
    EndIf
  EndIf
  ProcedureReturn *image
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;-METHODS.

;/////////////////////////////////////////////////////////////////////////////////
Procedure gdiPlus_ImageClass_Destroy(*this._gdiPlus_Image_Template)
  GdipDisposeImage(*this\object)
  FreeMemory(*this)
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
Procedure.i gdiPlus_ImageClass_Clone(*this._gdiPlus_Image_Template)
  Protected *image._gdiPlus_Image_Template, t1
  If GdipCloneImage(*this\object, @t1) = #ok
    *image = AllocateMemory(SizeOf(_gdiPlus_Image_Template))
    If *image 
      *image\vTable = ?_gdiPlus_Image_Template_VT
      *image\object = t1
    Else
      GdipDisposeImage(t1)
    EndIf
  EndIf
  ProcedureReturn *image
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
Procedure.i gdiPlus_ImageClass_CloneAreaF(*this._gdiPlus_Image_Template, x.f, y.f, width.f, height.f, format)
  Protected *image._gdiPlus_Image_Template, t1
  If GdipCloneBitmapArea(x, y, width, height, format, *this\object, @t1) = #ok
    *image = AllocateMemory(SizeOf(_gdiPlus_Image_Template))
    If *image 
      *image\vTable = ?_gdiPlus_Image_Template_VT
      *image\object = t1
    Else
      GdipDisposeImage(t1)
    EndIf
  EndIf
  ProcedureReturn *image
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
Procedure.i gdiPlus_ImageClass_CloneAreaI(*this._gdiPlus_Image_Template, x, y, width, height, format)
  Protected *image._gdiPlus_Image_Template, t1
  If GdipCloneBitmapAreaI(x, y, width, height, format, *this\object, @t1) = #ok
    *image = AllocateMemory(SizeOf(_gdiPlus_Image_Template))
    If *image 
      *image\vTable = ?_gdiPlus_Image_Template_VT
      *image\object = t1
    Else
      GdipDisposeImage(t1)
    EndIf
  EndIf
  ProcedureReturn *image
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
Procedure.i gdiPlus_ImageClass_GetBounds(*this._gdiPlus_Image_Template, *srcRect.RectF, *srcUnit.INTEGER)
  Protected result
  result = GdipGetImageBounds(*this\object, *srcRect, *srcUnit)
  ProcedureReturn result
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
Procedure.i gdiPlus_ImageClass_GetFlags(*this._gdiPlus_Image_Template)
  Protected result
  GdipGetImageFlags(*this\object, @result)
  ProcedureReturn result
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
Procedure.i gdiPlus_ImageClass_GetHBITMAP(*this._gdiPlus_Image_Template, backColor)
  Protected result
  GdipCreateHBITMAPFromBitmap(*this\object, @result, backColor)
  ProcedureReturn result
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
Procedure.i gdiPlus_ImageClass_GetHeight(*this._gdiPlus_Image_Template)
  Protected result
  GdipGetImageHeight(*this\object, @result)
  ProcedureReturn result
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
Procedure.i gdiPlus_ImageClass_GetHICON(*this._gdiPlus_Image_Template, backColor)
  Protected result
  GdipCreateHICONFromBitmap(*this\object, @result)
  ProcedureReturn result
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
Procedure.f gdiPlus_ImageClass_GetHorizontalResolution(*this._gdiPlus_Image_Template)
  Protected result.f
  GdipGetImageHorizontalResolution(*this\object, @result)
  ProcedureReturn result
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
Procedure.i gdiPlus_ImageClass_GetPalette(*this._gdiPlus_Image_Template, *palette.ColorPalette, size)
  Protected result
  result = GdipGetImagePalette(*this\object, *palette.ColorPalette, size)
  ProcedureReturn result
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
Procedure.i gdiPlus_ImageClass_GetPaletteSize(*this._gdiPlus_Image_Template)
  Protected result
  GdipGetImagePaletteSize(*this\object, @result)
  ProcedureReturn result
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
Procedure.i gdiPlus_ImageClass_GetPixel(*this._gdiPlus_Image_Template, x, y)
  Protected result
  GdipBitmapGetPixel(*this\object, x, y, @result)
  ProcedureReturn result
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
Procedure.i gdiPlus_ImageClass_GetPixelFormat(*this._gdiPlus_Image_Template)
  Protected result
  GdipGetImagePixelFormat(*this\object, @result)
  ProcedureReturn result
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
Procedure.i gdiPlus_ImageClass_GetRawFormat(*this._gdiPlus_Image_Template)
  Protected result, format.GUID
  If GdipGetImageRawFormat(*this\object, format) = #ok
    If CompareMemory(format, ?GUID_ImageFormatUndefined, SizeOf(GUID))
      result = #GDIPLUS_UNDEFINED
    ElseIf CompareMemory(format, ?GUID_ImageFormatMemoryBMP, SizeOf(GUID))  
      result = #GDIPLUS_MEMORYBMP
    ElseIf CompareMemory(format, ?GUID_ImageFormatBMP, SizeOf(GUID))  
      result = #GDIPLUS_BMP 
    ElseIf CompareMemory(format, ?GUID_ImageFormatEMF, SizeOf(GUID))  
      result = #GDIPLUS_EMF
    ElseIf CompareMemory(format, ?GUID_ImageFormatWMF, SizeOf(GUID))  
      result = #GDIPLUS_WMF
    ElseIf CompareMemory(format, ?GUID_ImageFormatJPEG, SizeOf(GUID))  
      result = #GDIPLUS_JPEG 
    ElseIf CompareMemory(format, ?GUID_ImageFormatPNG, SizeOf(GUID))  
      result = #GDIPLUS_PNG
    ElseIf CompareMemory(format, ?GUID_ImageFormatGIF, SizeOf(GUID))  
      result = #GDIPLUS_GIF
    ElseIf CompareMemory(format, ?GUID_ImageFormatTIFF, SizeOf(GUID))  
      result = #GDIPLUS_TIFF
    ElseIf CompareMemory(format, ?GUID_ImageFormatEXIF, SizeOf(GUID))  
      result = #GDIPLUS_EXIF
    ElseIf CompareMemory(format, ?GUID_ImageFormatPhotoCD, SizeOf(GUID))  
      result = #GDIPLUS_PHOTOCD
    ElseIf CompareMemory(format, ?GUID_ImageFormatFlashPIX, SizeOf(GUID))  
      result = #GDIPLUS_FLASHPIX
    ElseIf CompareMemory(format, ?GUID_ImageFormatIcon, SizeOf(GUID))  
      result = #GDIPLUS_FLASHICON
    EndIf
  EndIf
  ProcedureReturn result
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
Procedure.f gdiPlus_ImageClass_GetVerticalResolution(*this._gdiPlus_Image_Template)
  Protected result.f
  GdipGetImageVerticalResolution(*this\object, @result)
  ProcedureReturn result
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
Procedure.i gdiPlus_ImageClass_GetWidth(*this._gdiPlus_Image_Template)
  Protected result
  GdipGetImageWidth(*this\object, @result)
  ProcedureReturn result
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
Procedure.i gdiPlus_ImageClass_RotateFlip(*this._gdiPlus_Image_Template, rfType)
  Protected result
  result = GdipImageRotateFlip(*this\object, rfType)
  ProcedureReturn result
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
Procedure.i gdiPlus_ImageClass_Save(*this._gdiPlus_Image_Template, fileName$, type, *params._gdiPlus_EncoderParameters_Template=0)
  Protected result, clsidPtr, encoder
  If fileName$
    Select type
      Case #GDIPLUS_BMP
        clsidPtr = ?GUID_ImageEncoderBMP
      Case #GDIPLUS_JPEG
        clsidPtr = ?GUID_ImageEncoderJPEG
      Case #GDIPLUS_GIF
        clsidPtr = ?GUID_ImageEncoderGIF
      Case #GDIPLUS_TIFF
        clsidPtr = ?GUID_ImageEncoderTIFF
      Case #GDIPLUS_PNG
        clsidPtr = ?GUID_ImageEncoderPNG
    EndSelect
    If clsidPtr
      If *params And *params\encoderParameters\Count > 0
        encoder = *params\encoderParameters
      EndIf
      result = GdipSaveImageToFile(*this\object, fileName$, clsidPtr, encoder)
    Else
      result = #UnknownImageFormat
    EndIf
  EndIf
  ProcedureReturn result
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
Procedure.i gdiPlus_ImageClass_SaveToMemory(*this._gdiPlus_Image_Template, type, *size.INTEGER=0, *params._gdiPlus_EncoderParameters_Template=0)
  Protected *mem, stream.iStream, clsidPtr, encoder, numBytes, numBytesRead
  ;Create a stream object to house the image data.
    If CreateStreamOnHGlobal_(0, #True, @stream) = #S_OK
      Select type
        Case #GDIPLUS_BMP
          clsidPtr = ?GUID_ImageEncoderBMP
        Case #GDIPLUS_JPEG
          clsidPtr = ?GUID_ImageEncoderJPEG
        Case #GDIPLUS_GIF
          clsidPtr = ?GUID_ImageEncoderGIF
        Case #GDIPLUS_TIFF
          clsidPtr = ?GUID_ImageEncoderTIFF
        Case #GDIPLUS_PNG
          clsidPtr = ?GUID_ImageEncoderPNG
      EndSelect
      If clsidPtr
        If *params And *params\encoderParameters\Count > 0
          encoder = *params\encoderParameters
        EndIf
        If GdipSaveImageToStream(*this\object, stream, clsidPtr, encoder) = #ok
          stream\Seek(0, #STREAM_SEEK_END, @numBytes)
          stream\Seek(0, #STREAM_SEEK_SET, 0)
          If numBytes
            *mem = AllocateMemory(numBytes)
            If *mem
              stream\Read(*mem, numBytes, @numBytesRead)
              If numBytesRead = numBytes
                If *size
                  *size\i = numBytes
                EndIf
              Else
                FreeMemory(*mem)
                *mem = 0
              EndIf
            EndIf
          EndIf
        EndIf
      EndIf
      stream\Release()
    EndIf
  ProcedureReturn *mem
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
Procedure.i gdiPlus_ImageClass_SetPalette(*this._gdiPlus_Image_Template, *palette.ColorPalette)
  Protected result
  result = GdipSetImagePalette(*this\object, *palette.ColorPalette)
  ProcedureReturn result
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
Procedure.i gdiPlus_ImageClass_SetPixel(*this._gdiPlus_Image_Template, x, y, ARGBColor)
  Protected result
  result = GdipBitmapSetPixel(*this\object, x, y, ARGBColor)
  ProcedureReturn result
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
Procedure.i gdiPlus_ImageClass_SetResolution(*this._gdiPlus_Image_Template, xdpi.f, ydpi.f)
  Protected result
  result = GdipBitmapSetResolution(*this\object, xdpi, ydpi)
  ProcedureReturn result
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
Procedure.i gdiPlus_ImageClass_LockBits(*this._gdiPlus_Image_Template, *rc.RECT, flags, pixelFormat, *lockedBitmapData.BitmapData)
  Protected result
  result = GdipBitmapLockBits(*this\object, *rc, flags, pixelFormat, *lockedBitmapData)
  ProcedureReturn result
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
Procedure.i gdiPlus_ImageClass_UnLockBits(*this._gdiPlus_Image_Template, *lockedBitmapData.BitmapData)
  Protected result
  result = GdipBitmapUnLockBits(*this\object, *lockedBitmapData)
  ProcedureReturn result
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
Procedure.i gdiPlus_ImageClass_GetFrameCount(*this._gdiPlus_Image_Template, dimension)
  Protected result, guiPtr
  Select dimension
    Case #GDIPLUS_FRAMEDIMENSIONTIME
      guiPtr = ?GUID_FrameDimensionTime
    Case #GDIPLUS_FRAMEDIMENSIONRESOLUTION
      guiPtr = ?GUID_FrameDimensionResolution
    Case #GDIPLUS_FRAMEDIMENSIONPAGE
      guiPtr = ?GUID_FrameDimensionPage
  EndSelect
  If guiPtr
    GdipImageGetFrameCount(*this\object, guiPtr, @result)
  EndIf
  ProcedureReturn result
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
Procedure.i gdiPlus_ImageClass_SaveAdd(*this._gdiPlus_Image_Template, *params._gdiPlus_EncoderParameters_Template=0)
  Protected result, encoder
  If *params And *params\encoderParameters\Count > 0
    encoder = *params\encoderParameters
  EndIf
  result = GdipSaveAdd(*this\object, encoder)
  ProcedureReturn result
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
Procedure.i gdiPlus_ImageClass_SaveAddImage(*this._gdiPlus_Image_Template, *newImage._gdiPlus_Image_Template, *params._gdiPlus_EncoderParameters_Template=0)
  Protected result, encoder
  If *newImage
    If *params And *params\encoderParameters\Count > 0
      encoder = *params\encoderParameters
    EndIf
    result = GdipSaveAddImage(*this\object, *newImage\object, encoder)
  Else
    result = #InvalidParameter  
  EndIf  
  ProcedureReturn result
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
Procedure.i gdiPlus_ImageClass_SelectActiveFrame(*this._gdiPlus_Image_Template, dimension, index)
  Protected result, guiPtr
  Select dimension
    Case #GDIPLUS_FRAMEDIMENSIONTIME
      guiPtr = ?GUID_FrameDimensionTime
    Case #GDIPLUS_FRAMEDIMENSIONRESOLUTION
      guiPtr = ?GUID_FrameDimensionResolution
    Case #GDIPLUS_FRAMEDIMENSIONPAGE
      guiPtr = ?GUID_FrameDimensionPage
  EndSelect
  If guiPtr
    result = GdipImageSelectActiveFrame(*this\object, guiPtr, index)
  EndIf
  ProcedureReturn result
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
Procedure.i gdiPlus_ImageClass_GetPropertyCount(*this._gdiPlus_Image_Template)
  Protected result
  GdipGetPropertyCount(*this\object, @result)
  ProcedureReturn result
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
Procedure.i gdiPlus_ImageClass_GetPropertyIdList(*this._gdiPlus_Image_Template, numProperties, *buffer)
  Protected result
  result = GdipGetPropertyIdList(*this\object, numProperties, *buffer)
  ProcedureReturn result
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
Procedure.i gdiPlus_ImageClass_GetPropertyItem(*this._gdiPlus_Image_Template, propId, propSize, *propItem.PropertyItem)
  Protected result
  result = GdipGetPropertyItem(*this\object, propID, propSize, *propItem)
  ProcedureReturn result
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
Procedure.i gdiPlus_ImageClass_GetPropertyItemSize(*this._gdiPlus_Image_Template, propId)
  Protected result
  GdipGetPropertyItemSize(*this\object, propID, @result)
  ProcedureReturn result
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
Procedure.i gdiPlus_ImageClass_RemovePropertyItem(*this._gdiPlus_Image_Template, propId)
  Protected result
  result = GdipRemovePropertyItem(*this\object, propId)
  ProcedureReturn result
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
Procedure.i gdiPlus_ImageClass_SetPropertyItem(*this._gdiPlus_Image_Template, *item.PropertyItem)
  Protected result
  result = GdipSetPropertyItem(*this\object, *item)
  ProcedureReturn result
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
;-VIRTUAL TABLE.
DataSection
  _gdiPlus_Image_Template_VT:
    Data.i @gdiPlus_BaseClass_GetGdiPlusHandle()
    Data.i @gdiPlus_ImageClass_Destroy()
    Data.i @gdiPlus_ImageClass_Clone()
    Data.i @gdiPlus_ImageClass_CloneAreaF()
    Data.i @gdiPlus_ImageClass_CloneAreaI()
    Data.i @gdiPlus_ImageClass_GetBounds()
    Data.i @gdiPlus_ImageClass_GetFlags()
    Data.i @gdiPlus_ImageClass_GetHBITMAP()
    Data.i @gdiPlus_ImageClass_GetHeight()
    Data.i @gdiPlus_ImageClass_GetHICON()
    Data.i @gdiPlus_ImageClass_GetHorizontalResolution()
    Data.i @gdiPlus_ImageClass_GetPalette()
    Data.i @gdiPlus_ImageClass_GetPaletteSize()
    Data.i @gdiPlus_ImageClass_GetPixel()
    Data.i @gdiPlus_ImageClass_GetPixelFormat()
    Data.i @gdiPlus_ImageClass_GetRawFormat()
    Data.i @gdiPlus_ImageClass_GetVerticalResolution()
    Data.i @gdiPlus_ImageClass_GetWidth()
    Data.i @gdiPlus_ImageClass_RotateFlip()
    Data.i @gdiPlus_ImageClass_Save()
    Data.i @gdiPlus_ImageClass_SaveToMemory()
    Data.i @gdiPlus_ImageClass_SetPalette()
    Data.i @gdiPlus_ImageClass_SetPixel()
    Data.i @gdiPlus_ImageClass_SetResolution()
    Data.i @gdiPlus_ImageClass_LockBits()
    Data.i @gdiPlus_ImageClass_UnLockBits()
    Data.i @gdiPlus_ImageClass_GetFrameCount()
    Data.i @gdiPlus_ImageClass_SaveAdd()
    Data.i @gdiPlus_ImageClass_SaveAddImage()
    Data.i @gdiPlus_ImageClass_SelectActiveFrame()
    Data.i @gdiPlus_ImageClass_GetPropertyCount()
    Data.i @gdiPlus_ImageClass_GetPropertyIdList()
    Data.i @gdiPlus_ImageClass_GetPropertyItem()
    Data.i @gdiPlus_ImageClass_GetPropertyItemSize()
    Data.i @gdiPlus_ImageClass_RemovePropertyItem()
    Data.i @gdiPlus_ImageClass_SetPropertyItem()
EndDataSection
;/////////////////////////////////////////////////////////////////////////////////

; IDE Options = PureBasic 4.51 (Windows - x86)
; ExecutableFormat = Shared Dll
; CursorPosition = 163
; FirstLine = 144
; Folding = --------
; Markers = 5
; EnableUnicode
; EnableXP
; Executable = nxReportU.dll