﻿;/////////////////////////////////////////////////////////////////////////////////
;***GDI+ wrapper file***
;=======================
;
;LinearGradientBrush class.
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
;-INTERFACE.

  ;All methods return a gdiPlus status code (0 for okay) unless otherwise stated.
  Interface gdiPlus_LinearGradientBrush Extends gdiPlus_Brush
    Clone.i()                                                     ;Returns, if successful, a new gdiPlus_LinearGradientBrush object containing an exact copy of the original object.
    GetBlend.i(*blends, *positions, count)                        ;*blends and *positions should both point to an array of floats.
    GetBlendCount.i()                                             ;Returns the number of blend factors currently set for this brush.
    GetGammaCorrection.i()                                        ;Returns #True if gamma correction is enabled.
    GetInterpolationColorCount.i()                                ;Returns the number of colors currently set to be interpolated for this linear gradient brush.
    GetInterpolationColors.i(*blendColors, *positions, count)     ;*blendColors should point to an array of ARGB values.
                                                                  ;*positions should point to an array of floats.
    GetLinearColors.i(*colors)                                    ;*colors must point to an array large enough for 2 ARGB values.
    GetRectF.i(*rc.RectF)
    GetRectI.i(*rc.RectI)
    GetTransform.i(*matrix._gdiPlus_Matrix_Template)
    GetWrapMode.i()                                               ;Returns a WrapMode constant, e.g. #WrapModeTile.
    MultiplyTransform.i(*matrix._gdiPlus_Matrix_Template, matrixOrder=#MatrixOrderPrepend)
                                                                  ;Updates this brush's transformation matrix with the product of itself and another matrix.
    ResetTransform.i()                                            ;Resets the transformation matrix of this linear gradient brush to the identity matrix. 
    RotateTransform.i(angle.f, matrixOrder=#MatrixOrderPrepend)   ;Updates this brush's current transformation matrix with the product of itself and a rotation matrix.
    ScaleTransform.i(sx.f, sy.f, matrixOrder=#MatrixOrderPrepend) ;Updates this brush's current transformation matrix with the product of itself and a scaling matrix.
    SetBlend.i(*blends, *positions, count)                        ;*blends and *positions should both point to an array of floats with values between 0 and 1.
    SetBlendBellShape.i(focus.f, scale.f)                         ;Both parameters should be between 0 and 1.
    SetBlendTriangularShape.i(focus.f, scale.f)                   ;Both parameters should be between 0 and 1.
    SetGammaCorrection.i(blnUseGammaCorrection)
    SetInterpolationColors.i(*blendColors, *positions, count)     ;*blendColors should point to an array of ARGB values.
                                                                  ;*positions should point to an array of floats with values between 0 and 1.
    SetLinearColors.i(color1, color2)
    SetTransform.i(*matrix._gdiPlus_Matrix_Template)              ;Sets the transformation matrix of this linear gradient brush.
    SetWrapMode.i(wrapMode)                                       ;wrapMode = a WrapMode constant, e.g. #WrapModeTile.
    TranslateTransform.i(dx.f, dy.f, matrixOrder=#MatrixOrderPrepend)
                                                                  ;Updates this brush's current transformation matrix with the product of itself and a translation matrix.
  EndInterface
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
;-CLASS TEMPLATE.

  Macro _gdiPlus_LinearGradientBrush_Template
    _gdiPlus_GenericObject_Template
  EndMacro
;/////////////////////////////////////////////////////////////////////////////////


;-CONSTRUCTORS.

;/////////////////////////////////////////////////////////////////////////////////
;Returns, if successful, a gdiPlus_LinearGradientBrush object pointer.
Procedure.i gdiPlus_CreateLinearGradientBrushFromPointF(*point1.PointF, *point2.PointF, color1, color2, wrapMode=#WrapModeTile)
  Protected *brush._gdiPlus_LinearGradientBrush_Template
  *brush = AllocateMemory(SizeOf(_gdiPlus_LinearGradientBrush_Template))
  If *brush
    *brush\vTable = ?_gdiPlus_LinearGradientBrush_Template_VT
    If GdipCreateLineBrush(*point1, *point2, color1, color2, wrapMode, @*brush\object) <> #Ok
      FreeMemory(*brush)
      *brush = 0
    EndIf
  EndIf
  ProcedureReturn *brush
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
;Returns, if successful, a gdiPlus_LinearGradientBrush object pointer.
Procedure.i gdiPlus_CreateLinearGradientBrushFromPointI(*point1.Point, *point2.Point, color1, color2, wrapMode=#WrapModeTile)
  Protected *brush._gdiPlus_LinearGradientBrush_Template
  *brush = AllocateMemory(SizeOf(_gdiPlus_LinearGradientBrush_Template))
  If *brush
    *brush\vTable = ?_gdiPlus_LinearGradientBrush_Template_VT
    If GdipCreateLineBrushI(*point1, *point2, color1, color2, wrapMode, @*brush\object) <> #Ok
      FreeMemory(*brush)
      *brush = 0
    EndIf
  EndIf
  ProcedureReturn *brush
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
;Returns, if successful, a gdiPlus_LinearGradientBrush object pointer.
Procedure.i gdiPlus_CreateLinearGradientBrushFromRectF(*rc.RectF, color1, color2, mode=#LinearGradientModeHorizontal, wrapMode=#WrapModeTile)
  Protected *brush._gdiPlus_LinearGradientBrush_Template
  *brush = AllocateMemory(SizeOf(_gdiPlus_LinearGradientBrush_Template))
  If *brush
    *brush\vTable = ?_gdiPlus_LinearGradientBrush_Template_VT
    If GdipCreateLineBrushFromRect(*rc, color1, color2, mode, wrapMode, @*brush\object) <> #Ok
      FreeMemory(*brush)
      *brush = 0
    EndIf
  EndIf
  ProcedureReturn *brush
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
;Returns, if successful, a gdiPlus_LinearGradientBrush object pointer.
Procedure.i gdiPlus_CreateLinearGradientBrushFromRectI(*rc.RectI, color1, color2, mode=#LinearGradientModeHorizontal, wrapMode=#WrapModeTile)
  Protected *brush._gdiPlus_LinearGradientBrush_Template
  *brush = AllocateMemory(SizeOf(_gdiPlus_LinearGradientBrush_Template))
  If *brush
    *brush\vTable = ?_gdiPlus_LinearGradientBrush_Template_VT
    If GdipCreateLineBrushFromRectI(*rc, color1, color2, mode, wrapMode, @*brush\object) <> #Ok
      FreeMemory(*brush)
      *brush = 0
    EndIf
  EndIf
  ProcedureReturn *brush
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;-METHODS.

;/////////////////////////////////////////////////////////////////////////////////
Procedure.i gdiPlus_LinearGradientBrushClass_Clone(*this._gdiPlus_LinearGradientBrush_Template)
  Protected *brush._gdiPlus_LinearGradientBrush_Template, t1
  If GdipCloneBrush(*this\object, @t1) = #ok
    *brush = AllocateMemory(SizeOf(_gdiPlus_LinearGradientBrush_Template))
    If *brush
      *brush\vTable = ?_gdiPlus_LinearGradientBrush_Template_VT
      *brush\object = t1
    Else
      GdipDeleteBrush(t1)
    EndIf
  EndIf
  ProcedureReturn *brush
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
Procedure.i gdiPlus_LinearGradientBrushClass_GetBlend(*this._gdiPlus_LinearGradientBrush_Template, *blends, *positions, count)
  Protected result
  result = GdipGetLineBlend(*this\object, *blends, *positions, count)
  ProcedureReturn result
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
Procedure.i gdiPlus_LinearGradientBrushClass_GetBlendCount(*this._gdiPlus_LinearGradientBrush_Template)
  Protected result
  GdipGetLineBlendCount(*this\object, @result)
  ProcedureReturn result
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
Procedure.i gdiPlus_LinearGradientBrushClass_GetGammaCorrection(*this._gdiPlus_LinearGradientBrush_Template)
  Protected result
  GdipGetLineGammaCorrection(*this\object, @result)
  ProcedureReturn result
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
Procedure.i gdiPlus_LinearGradientBrushClass_GetInterpolationColorCount(*this._gdiPlus_LinearGradientBrush_Template)
  Protected result
  GdipGetLinePresetBlendCount(*this\object, @result)
  ProcedureReturn result
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
Procedure.i gdiPlus_LinearGradientBrushClass_GetInterpolationColors(*this._gdiPlus_LinearGradientBrush_Template, *blendColors, *positions, count)
  Protected result
  result = GdipGetLinePresetBlend(*this\object, *blendColors, *positions, count)
  ProcedureReturn result
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
Procedure.i gdiPlus_LinearGradientBrushClass_GetLinearColors(*this._gdiPlus_LinearGradientBrush_Template, *Colors)
  Protected result
  result = GdipGetLineColors(*this\object, *Colors)
  ProcedureReturn result
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
Procedure.i gdiPlus_LinearGradientBrushClass_GetRectF(*this._gdiPlus_LinearGradientBrush_Template, *rc.RectF)
  Protected result
  result = GdipGetLineRect(*this\object, *rc)
  ProcedureReturn result
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
Procedure.i gdiPlus_LinearGradientBrushClass_GetRectI(*this._gdiPlus_LinearGradientBrush_Template, *rc.RectI)
  Protected result
  result = GdipGetLineRectI(*this\object, *rc)
  ProcedureReturn result
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
Procedure.i gdiPlus_LinearGradientBrushClass_GetTransform(*this._gdiPlus_LinearGradientBrush_Template, *matrix._gdiPlus_Matrix_Template)
  Protected result
  If *matrix
    result = GdipGetLineTransform(*this\object, *matrix\object)
  Else
    result = #InvalidParameter
  EndIf
  ProcedureReturn result
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
Procedure.i gdiPlus_LinearGradientBrushClass_GetWrapMode(*this._gdiPlus_LinearGradientBrush_Template)
  Protected result
  GdipGetLineWrapMode(*this\object, @result)
  ProcedureReturn result
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
Procedure.i gdiPlus_LinearGradientBrushClass_MultiplyTransform(*this._gdiPlus_LinearGradientBrush_Template, *matrix._gdiPlus_Matrix_Template, matrixOrder=#MatrixOrderPrepend)
  Protected result
  result = GdipMultiplyLineTransform(*this\object, *matrix\object, matrixOrder)
  ProcedureReturn result
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
Procedure.i gdiPlus_LinearGradientBrushClass_ResetTransform(*this._gdiPlus_LinearGradientBrush_Template)
  Protected result
  result = GdipResetLineTransform(*this\object)
  ProcedureReturn result
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
Procedure.i gdiPlus_LinearGradientBrushClass_RotateTransform(*this._gdiPlus_LinearGradientBrush_Template, angle.f, matrixOrder=#MatrixOrderPrepend)
  Protected result
  result = GdipRotateLineTransform(*this\object, angle, matrixOrder)
  ProcedureReturn result
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
Procedure.i gdiPlus_LinearGradientBrushClass_ScaleTransform(*this._gdiPlus_LinearGradientBrush_Template, sx.f, sy.f, matrixOrder=#MatrixOrderPrepend)
  Protected result
  result = GdipScaleLineTransform(*this\object, sx, sy, matrixOrder)
  ProcedureReturn result
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
Procedure.i gdiPlus_LinearGradientBrushClass_SetBlend(*this._gdiPlus_LinearGradientBrush_Template, *blends, *positions, count)
  Protected result
  result = GdipSetLineBlend(*this\object, *blends, *positions, count)
  ProcedureReturn result
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
Procedure.i gdiPlus_LinearGradientBrushClass_SetBlendBellShape(*this._gdiPlus_LinearGradientBrush_Template, focus.f, scale.f)
  Protected result
  result = GdipSetLineSigmaBlend(*this\object, focus, scale)
  ProcedureReturn result
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
Procedure.i gdiPlus_LinearGradientBrushClass_SetBlendTriangularShape(*this._gdiPlus_LinearGradientBrush_Template, focus.f, scale.f)
  Protected result
  result = GdipSetLineLinearBlend(*this\object, focus, scale)
  ProcedureReturn result
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
Procedure.i gdiPlus_LinearGradientBrushClass_SetGammaCorrection(*this._gdiPlus_LinearGradientBrush_Template, blnUseGammaCorrection)
  Protected result
  result = GdipSetLineGammaCorrection(*this\object, blnUseGammaCorrection)
  ProcedureReturn result
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
Procedure.i gdiPlus_LinearGradientBrushClass_SetInterpolationColors(*this._gdiPlus_LinearGradientBrush_Template, *blendColors, *positions, count)
  Protected result
  result = GdipSetLinePresetBlend(*this\object, *blendColors, *positions, count)
  ProcedureReturn result
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
Procedure.i gdiPlus_LinearGradientBrushClass_SetLinearColors(*this._gdiPlus_LinearGradientBrush_Template, color1, color2)
  Protected result
  result = GdipSetLineColors(*this\object, color1, color2)
  ProcedureReturn result
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
Procedure.i gdiPlus_LinearGradientBrushClass_SetTransform(*this._gdiPlus_LinearGradientBrush_Template, *matrix._gdiPlus_Matrix_Template)
  Protected result
  If *matrix
    result = GdipSetLineTransform(*this\object, *matrix\object)
  Else
    result = #InvalidParameter
  EndIf
  ProcedureReturn result
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
Procedure.i gdiPlus_LinearGradientBrushClass_SetWrapMode(*this._gdiPlus_LinearGradientBrush_Template, wrapMode)
  Protected result
  result = GdipSetLineWrapMode(*this\object, wrapmode)
  ProcedureReturn result
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
Procedure.i gdiPlus_LinearGradientBrushClass_TranslateTransform(*this._gdiPlus_LinearGradientBrush_Template, dx.f, dy.f, matrixOrder=#MatrixOrderPrepend)
  Protected result
  result = GdipTranslateLineTransform(*this\object, dx, dy, matrixOrder)
  ProcedureReturn result
EndProcedure
;/////////////////////////////////////////////////////////////////////////////////


;/////////////////////////////////////////////////////////////////////////////////
;-VIRTUAL TABLE.
DataSection
  _gdiPlus_LinearGradientBrush_Template_VT:
    Data.i @gdiPlus_BaseClass_GetGdiPlusHandle()
    Data.i @gdiPlus_BrushClass_Destroy()
    Data.i @gdiPlus_BrushClass_GetType()
    Data.i @gdiPlus_LinearGradientBrushClass_Clone()
    Data.i @gdiPlus_LinearGradientBrushClass_GetBlend()
    Data.i @gdiPlus_LinearGradientBrushClass_GetBlendCount()
    Data.i @gdiPlus_LinearGradientBrushClass_GetGammaCorrection()
    Data.i @gdiPlus_LinearGradientBrushClass_GetInterpolationColorCount()
    Data.i @gdiPlus_LinearGradientBrushClass_GetInterpolationColors()
    Data.i @gdiPlus_LinearGradientBrushClass_GetLinearColors()
    Data.i @gdiPlus_LinearGradientBrushClass_GetRectF()
    Data.i @gdiPlus_LinearGradientBrushClass_GetRectI()
    Data.i @gdiPlus_LinearGradientBrushClass_GetTransform()
    Data.i @gdiPlus_LinearGradientBrushClass_GetWrapMode()
    Data.i @gdiPlus_LinearGradientBrushClass_MultiplyTransform()
    Data.i @gdiPlus_LinearGradientBrushClass_ResetTransform()
    Data.i @gdiPlus_LinearGradientBrushClass_RotateTransform()
    Data.i @gdiPlus_LinearGradientBrushClass_ScaleTransform()
    Data.i @gdiPlus_LinearGradientBrushClass_SetBlend()
    Data.i @gdiPlus_LinearGradientBrushClass_SetBlendBellShape()
    Data.i @gdiPlus_LinearGradientBrushClass_SetBlendTriangularShape()
    Data.i @gdiPlus_LinearGradientBrushClass_SetGammaCorrection()
    Data.i @gdiPlus_LinearGradientBrushClass_SetInterpolationColors()
    Data.i @gdiPlus_LinearGradientBrushClass_SetLinearColors()
    Data.i @gdiPlus_LinearGradientBrushClass_SetTransform()
    Data.i @gdiPlus_LinearGradientBrushClass_SetWrapMode()
    Data.i @gdiPlus_LinearGradientBrushClass_TranslateTransform()
EndDataSection
;/////////////////////////////////////////////////////////////////////////////////

; IDE Options = PureBasic 4.51 (Windows - x86)
; ExecutableFormat = Shared Dll
; CursorPosition = 37
; FirstLine = 6
; Folding = -----
; Markers = 5
; EnableUnicode
; EnableXP
; Executable = nxReportU.dll